<?php

return [
    'apache' => [
        'function.apache-',
        'function.virtual',
    ],
    'apcu' => [
        'function.apcu-',
    ],
    'bcmath' => [
        'function.bc\.+',
    ],
    'bzip2' => [
        'function.bz\.+',
    ],
    'commonmark' => [
        'function.commonmark-',
    ],
    'com_dotnet' => [
        'function.com-',
        'function.variant-',
    ],
    'componere' => [
        'componere.',
    ],
    'core' => [
        'function.abs',
        'function.acos',
        'function.acosh',
        'function.addcslashes',
        'function.addslashes',
        'function.array-',
        'function.arsort',
        'function.asin',
        'function.asinh',
        'function.asort',
        'function.atan',
        'function.atan2',
        'function.atanh',
        'function.base-convert',
        'function.base64-',
        'function.basename',
        'function.bin2hex',
        'function.bindec',
        'function.boolval',
        'function.cal-',
        'function.call-user-func',
        'function.call-user-func-array',
        'function.ceil',
        'function.chdir',
        'function.checkdate',
        'function.checkdnsrr',
        'function.chgrp',
        'function.chmod',
        'function.chop',
        'function.chown',
        'function.chr',
        'function.chroot',
        'function.chunk-split',
        'function.class-alias',
        'function.class-exists',
        'function.class-implements',
        'function.class-parents',
        'function.class-uses',
        'function.clearstatcache',
        'function.cli-',
        'function.closedir',
        'function.closelog',
        'function.compact',
        'function.connection-',
        'function.constant',
        'function.convert-cyr-string',
        'function.convert-uudecode',
        'function.convert-uuencode',
        'function.copy',
        'function.cos',
        'function.cosh',
        'function.count',
        'function.count-chars',
        'function.crc32',
        'function.create-function',
        'function.crypt',
        'function.ctype-',
        'function.current',
        'function.date',
        'function.debug-',
        'function.decbin',
        'function.dechex',
        'function.decoct',
        'function.define',
        'function.defined',
        'function.deg2rad',
        'function.delete',
        'function.die',
        'function.dir',
        'function.dirname',
        'function.disk-',
        'function.diskfreespace',
        'function.dl',
        'function.dns-check-record',
        'function.dns-get-mx',
        'function.dns-get-record',
        'function.dom-import-simplexml',
        'function.doubleval',
        'function.each',
        'function.easter-date',
        'function.easter-days',
        'function.enum-exists',
        'function.error-',
        'function.escapeshellarg',
        'function.escapeshellcmd',
        'function.eval',
        'function.exec',
        'function.exit',
        'function.exp',
        'function.explode',
        'function.expm1',
        'function.extension-loaded',
        'function.extract',
        'function.fastcgi-',
        'function.fclose',
        'function.fdatasync',
        'function.fdiv',
        'function.feof',
        'function.fflush',
        'function.fgetc',
        'function.fgetcsv',
        'function.fgets',
        'function.fgetss',
        'function.file',
        'function.file\.+',
        'function.filter-',
        'function.finfo-',
        'function.floatval',
        'function.flock',
        'function.floor',
        'function.flush',
        'function.fmod',
        'function.fnmatch',
        'function.fopen',
        'function.forward-static-call',
        'function.forward-static-call-array',
        'function.fpassthru',
        'function.fprintf',
        'function.fputcsv',
        'function.fputs',
        'function.fread',
        'function.frenchtojd',
        'function.fscanf',
        'function.fseek',
        'function.fsockopen',
        'function.fstat',
        'function.fsync',
        'function.ftell',
        'function.ftruncate',
        'function.func-get-arg',
        'function.func-get-args',
        'function.func-num-args',
        'function.function-exists',
        'function.fwrite',
        'function.gc-',
        'function.get-',
        'function.getallheaders',
        'function.getcwd',
        'function.getdate',
        'function.getenv',
        'function.gethostbyaddr',
        'function.gethostbyname',
        'function.gethostbynamel',
        'function.gethostname',
        'function.getlastmod',
        'function.getmxrr',
        'function.getmygid',
        'function.getmyinode',
        'function.getmypid',
        'function.getmyuid',
        'function.getopt',
        'function.getprotobyname',
        'function.getprotobynumber',
        'function.getrandmax',
        'function.getrusage',
        'function.getservbyname',
        'function.getservbyport',
        'function.gettimeofday',
        'function.gettype',
        'function.glob',
        'function.gmdate',
        'function.gmmktime',
        'function.gmstrftime',
        'function.gregoriantojd',
        'function.hash',
        'function.header',
        'function.header-register-callback',
        'function.header-remove',
        'function.headers-list',
        'function.headers-sent',
        'function.hebrev',
        'function.hebrevc',
        'function.hex2bin',
        'function.hexdec',
        'function.highlight-file',
        'function.highlight-string',
        'function.hrtime',
        'function.html-entity-decode',
        'function.htmlentities',
        'function.htmlspecialchars',
        'function.htmlspecialchars-decode',
        'function.http-build-query',
        'function.http-response-code',
        'function.hypot',
        'function.idate',
        'function.ignore-user-abort',
        'function.implode',
        'function.in-array',
        'function.inet-',
        'function.ini-',
        'function.intdiv',
        'function.interface-exists',
        'function.intval',
        'function.ip2long',
        'function.is-a',
        'function.is-array',
        'function.is-bool',
        'function.is-callable',
        'function.is-countable',
        'function.is-dir',
        'function.is-double',
        'function.is-executable',
        'function.is-file',
        'function.is-finite',
        'function.is-float',
        'function.is-infinite',
        'function.is-int',
        'function.is-integer',
        'function.is-iterable',
        'function.is-link',
        'function.is-long',
        'function.is-nan',
        'function.is-null',
        'function.is-numeric',
        'function.is-object',
        'function.is-readable',
        'function.is-resource',
        'function.is-scalar',
        'function.is-string',
        'function.is-subclass-of',
        'function.is-uploaded-file',
        'function.is-writable',
        'function.is-writeable',
        'function.iterator-',
        'function.jddayofweek',
        'function.jdmonthname',
        'function.jdtofrench',
        'function.jdtogregorian',
        'function.jdtojewish',
        'function.jdtojulian',
        'function.jdtounix',
        'function.jewishtojd',
        'function.join',
        'function.json-',
        'function.juliantojd',
        'function.key',
        'function.key-exists',
        'function.krsort',
        'function.ksort',
        'function.lcfirst',
        'function.lcg-value',
        'function.lchgrp',
        'function.lchown',
        'function.levenshtein',
        'function.libxml-',
        'function.link',
        'function.linkinfo',
        'function.list',
        'function.localeconv',
        'function.localtime',
        'function.log',
        'function.log10',
        'function.log1p',
        'function.long2ip',
        'function.lstat',
        'function.ltrim',
        'function.mail',
        'function.max',
        'function.md5',
        'function.md5-file',
        'function.memory-',
        'function.metaphone',
        'function.method-exists',
        'function.microtime',
        'function.mime-content-type',
        'function.min',
        'function.mkdir',
        'function.mktime',
        'function.money-format',
        'function.move-uploaded-file',
        'function.mt-',
        'function.natcasesort',
        'function.natsort',
        'function.net-get-interfaces',
        'function.next',
        'function.nl-langinfo',
        'function.nl2br',
        'function.number-format',
        'function.ob-',
        'function.octdec',
        'function.opcache-',
        'function.opendir',
        'function.openlog',
        'function.ord',
        'function.output-',
        'function.pack',
        'function.parse-ini-',
        'function.parse-str',
        'function.parse-url',
        'function.passthru',
        'function.password-',
        'function.pathinfo',
        'function.pclose',
        'function.pfsockopen',
        'function.php-ini-',
        'function.php-sapi-name',
        'function.php-strip-whitespace',
        'function.php-uname',
        'function.phpcredits',
        'function.phpdbg-',
        'function.phpinfo',
        'function.phpversion',
        'function.pi',
        'function.popen',
        'function.pos',
        'function.posix-',
        'function.pow',
        'function.preg-',
        'function.prev',
        'function.print-r',
        'function.printf',
        'function.proc-',
        'function.property-exists',
        'function.putenv',
        'function.quoted-printable-',
        'function.quotemeta',
        'function.rad2deg',
        'function.rand',
        'function.random-',
        'function.range',
        'function.rawurldecode',
        'function.rawurlencode',
        'function.readdir',
        'function.readfile',
        'function.readlink',
        'function.realpath',
        'function.register-shutdown-function',
        'function.register-tick-function',
        'function.rename',
        'function.reset',
        'function.restore-',
        'function.rewind',
        'function.rewinddir',
        'function.rmdir',
        'function.round',
        'function.rsort',
        'function.rtrim',
        'function.sapi-',
        'function.scandir',
        'function.seaslog-get-author',
        'function.seaslog-get-version',
        'function.serialize',
        'function.session-',
        'function.set-',
        'function.setcookie',
        'function.setlocale',
        'function.setrawcookie',
        'function.settype',
        'function.sha1',
        'function.sha1-file',
        'function.shell-exec',
        'function.show-source',
        'function.shuffle',
        'function.similar-text',
        'function.simplexml-',
        'function.sin',
        'function.sinh',
        'function.sizeof',
        'function.sleep',
        'function.socket-',
        'function.sodium-',
        'function.sort',
        'function.soundex',
        'function.spl-',
        'function.sprintf',
        'function.sqrt',
        'function.srand',
        'function.sscanf',
        'function.stat',
        'function.str-',
        'function.strcasecmp',
        'function.strchr',
        'function.strcmp',
        'function.strcoll',
        'function.strcspn',
        'function.stream-',
        'function.strftime',
        'function.strip-tags',
        'function.stripcslashes',
        'function.stripos',
        'function.stripslashes',
        'function.stristr',
        'function.strlen',
        'function.strnatcasecmp',
        'function.strnatcmp',
        'function.strncasecmp',
        'function.strncmp',
        'function.strpbrk',
        'function.strpos',
        'function.strptime',
        'function.strrchr',
        'function.strrev',
        'function.strripos',
        'function.strrpos',
        'function.strspn',
        'function.strstr',
        'function.strtok',
        'function.strtolower',
        'function.strtotime',
        'function.strtoupper',
        'function.strtr',
        'function.strval',
        'function.substr',
        'function.substr-compare',
        'function.substr-count',
        'function.substr-replace',
        'function.symlink',
        'function.sys-get-temp-dir',
        'function.sys-getloadavg',
        'function.syslog',
        'function.system',
        'function.tan',
        'function.tanh',
        'function.tempnam',
        'function.time',
        'function.timezone-',
        'function.tmpfile',
        'function.token-get-all',
        'function.token-name',
        'function.touch',
        'function.trait-exists',
        'function.trigger-error',
        'function.trim',
        'function.uasort',
        'function.ucfirst',
        'function.ucwords',
        'function.uksort',
        'function.umask',
        'function.uniqid',
        'function.unixtojd',
        'function.unlink',
        'function.unpack',
        'function.unregister-tick-function',
        'function.unserialize',
        'function.unset',
        'function.urldecode',
        'function.urlencode',
        'function.user-error',
        'function.usleep',
        'function.usort',
        'function.var-dump',
        'function.var-export',
        'function.version-compare',
        'function.vfprintf',
        'function.vprintf',
        'function.vsprintf',
        'function.wordwrap',
        'function.xml-',
        'function.zend-thread-id',
        'function.zend-version',
        'pdo.getavailabledrivers',
        'xmlwriter.',
    ],
    'cubrid' => [
        'function.cubrid-',
    ],
    'curl' => [
        'curlfile.',
        'function.curl-',
    ],
    'dba' => [
        'function.dba-',
    ],
    'dbase' => [
        'function.dbase-',
    ],
    'dio' => [
        'function.dio-',
    ],
    'eio' => [
        'function.eio-',
    ],
    'enchant' => [
        'function.enchant-',
    ],
    'exif' => [
        'function.exif-',
        'function.read-exif-',
    ],
    'expect' => [
        'function.expect-',
    ],
    'fann' => [
        'function.fann-',
    ],
    'fdf' => [
        'function.fdf-',
    ],
    'fpm' => [
        'function.fpm-'
    ],
    'ftp' => [
        'function.ftp-',
    ],
    'gearman' => [
        'gearmanclient.',
        'gearmantask.',
    ],
    'gettext' => [
        'function.bind-textdomain-codeset',
        'function.bindtextdomain',
        'function.dcgettext',
        'function.dcngettext',
        'function.dgettext',
        'function.dngettext',
        'function.gettext',
        'function.ngettext',
        'function.textdomain',
    ],
    'gd' => [
        'function.gd-',
        'function.getimagesize',
        'function.getimagesizefromstring',
        'function.image\.+',
        'function.iptcembed',
        'function.iptcparse',
    ],
    'gmp' => [
        'function.gmp-',
    ],
    'geoip' => [
        'function.geoip-',
    ],
    'gnupg' => [
        'function.gnupg-',
    ],
    'ibase' => [
        'function.fbird-',
        'function.ibase-',
    ],
    'ibm_db2' => [
        'function.db2-',
    ],
    'iconv' => [
        'function.iconv',
    ],
    'igbinary' => [
        'function.igbinary-',
    ],
    'imap' => [
        'function.imap-',
    ],
    'inotify' => [
        'function.inotify-',
    ],
    'intl' => [
        'collator.',
        'function.grapheme-',
        'function.idn-',
        'function.intl-',
        'intlcalendar.',
        'intldateformatter.',
        'intltimezone.',
        'locale.',
        'messageformatter.',
        'normalizer.',
        'numberformatter.',
        'resourcebundle.',
        'transliterator.',
    ],
    'language' => [
        'function.array\z',
        'function.assert',
        'function.echo',
        'function.empty',
        'function.halt-compiler',
        'function.isset',
        'function.print\z',
    ],
    'ldap' => [
        'function.ldap-',
    ],
    'lzf' => [
        'function.lzf-',
    ],
    'mailparse' => [
        'function.mailparse-',
    ],
    'mbstring' => [
        'function.mb-',
    ],
    'memcache' => [
        'function.memcache-',
    ],
    'mongodb' => [
        'function.mongodb.',
    ],
    'mqseries' => [
        'function.mqseries-',
    ],
    'mysqli' => [
        'mysqli-',
        'mysqli.',
        'function.mysqli-',
    ],
    'mysql-obsolete' => [
        'function.mysql-',
    ],
    'oauth' => [
        'function.oauth-',
    ],
    'obsolete_7' => [
        'function.autoload',
        'function.end',
        'function.ezmlm-hash',
        'function.is-real',
        'function.jpeg2wbmp',
        'function.mcrypt-',
        'function.mdecrypt-',
        'function.png2wbmp',
        'function.wddx-',
    ],
    'obsolete_8' => [
        'function.mhash',
        'function.utf8-decode',
        'function.utf8-encode',
        'function.zip-',
    ],
    'oci8' => [
        'function.oci\.+',
    ],
    'odbc' => [
        'function.odbc-',
    ],
    'openal' => [
        'function.openal-',
    ],
    'openssl' => [
        'function.openssl-',
    ],
    'parallel' => [
        'parallel.',
    ],
    'pcntl' => [
        'function.pcntl-',
    ],
    'pgsql' => [
        'function.pg-',
    ],
    'ps' => [
        'function.ps-',
    ],
    'pspell' => [
        'function.pspell-',
    ],
    'radius' => [
        'function.radius-',
    ],
    'rar' => [
        'function.rar-',
        'rararchive.',
    ],
    'readline' => [
        'function.readline',
    ],
    'recode' => [
        'function.recode',
    ],
    'runkit7' => [
        'function.runkit7-',
    ],
    'rpminfo' => [
        'function.rpm\.+',
    ],
    'rrd' => [
        'function.rrd-',
        'function.rrdc-',
    ],
    'scoutapm' => [
        'function.scoutapm-',
    ],
    'shmop' => [
        'function.shmop-',
    ],
    'sqlsrv' => [
        'function.sqlsrv-',
    ],
    'smnp' => [
        'function.snmp-',
        'function.snmp2-',
        'function.snmp3-',
        'function.snmp\.+',
    ],
    'soap' => [
        'function.is-soap-fault',
        'function.use-soap-error-handler',
    ],
    'solr' => [
        'function.solr-',
    ],
    'ssdeep' => [
        'function.ssdeep-',
    ],
    'ssh2' => [
        'function.ssh2-',
    ],
    'stats' => [
        'function.stats-',
    ],
    'stomp' => [
        'function.stomp-',
        'stomp.',
    ],
    'svn' => [
        'function.svn-',
    ],
    'swoole' => [
        'function.swoole-',
        'swoole-server.',
    ],
    'sysvshm' => [
        'function.ftok',
        'function.sem-',
        'function.shm-',
        'function.msg-get-queue',
        'function.msg-queue-exists',
        'function.msg-receive',
        'function.msg-remove-queue',
        'function.msg-send',
        'function.msg-set-queue',
        'function.msg-stat-queue',
    ],
    'taint' => [
        'function.is-tainted',
        'function.taint',
        'function.untaint',
    ],
    'tcpwrap' => [
        'function.tcpwrap-',
    ],
    'tidy' => [
        'function.tidy-',
        'tidy.',
    ],
    'trader' => [
        'function.trader-',
    ],
    'ui' => [
        'function.ui-',
    ],
    'uopz' => [
        'function.uopz-',
    ],
    'var_representation' => [
        'function.var-representation',
    ],
    'win32service' => [
        'function.win32-',
    ],
    'wincache' => [
        'function.wincache-',
    ],
    'xattr' => [
        'function.xattr-',
    ],
    'xdiff' => [
        'function.xdiff-',
    ],
    'xhprof' => [
        'function.xhprof-',
    ],
    'xmlrpc' => ['function.xmlrpc-'],
    'yaml' => [
        'function.yaml-',
    ],
    'yaz' => [
        'function.yaz-',
    ],
    'zlib' => [
        'function.deflate-',
        'function.gz\.+',
        'function.inflate-',
        'function.readgzfile',
        'function.zlib-',
    ],
    'zookeeper' => [
        'function.zookeeper-',
    ]
];
